==> u%2B%2B_5.0.1.orig.tar.gz: u++-5.0.1/src/collection/example_Stack.cc <==
#include "uStack.h"
#include "stream.h"

class fred : public uColable {
  public:
    int i;
    fred( int p ) { i = p; }
};

class mary: public fred {
  public:
    mary( int i ) : fred( i ) {}
};

main() {
    uStack<fred> foo;
    uStackGen<fred> foogen( foo );
    uStack<mary> bar;
    uStackGen<mary> bargen( bar );
    fred *f;
    mary *m;
    int i;

    // fred test

    for ( ; foogen >> f; ) {
	cout << f->i << " ";
    }
    cout << "\n";
    
    for ( i = 0; i < 10; i += 1 ) {
	foo.uPush( new fred( 2 * i ) );
    }

    for ( foogen.uOver( foo ); foogen >> f; ) {
	cout << f->i << " ";
    }
    cout << "\n";
    
    for ( i = 0; i < 9; i += 1 ) {
	foo.uPop();
    }

    for ( foogen.uOver( foo ); foogen >> f; ) {
	cout << f->i << " ";
    }
    cout << "\n";
    
    for ( i = 0; i < 10; i += 1 ) {
	foo.uPush( new fred( 2 * i + 1 ) );
    }
    for ( foogen.uOver( foo ); foogen >> f; ) {
	cout << f->i << " ";
    }
    cout << "\n";

    // mary test

    for ( ; bargen >> m; ) {
	cout << m->i << " ";
    }
    cout << "\n";
    
    for ( i = 0; i < 10; i += 1 ) {
	bar.uPush( new mary( 2 * i ) );
    }

    for ( bargen.uOver( bar ); bargen >> m; ) {
	cout << m->i << " ";
    }
    cout << "\n";
    
    for ( i = 0; i < 9; i += 1 ) {
	bar.uPop();
    }

    for ( bargen.uOver( bar ); bargen >> m; ) {
	cout << m->i << " ";
    }
    cout << "\n";
    
    for ( i = 0; i < 10; i += 1 ) {
	bar.uPush( new mary( 2 * i + 1 ) );
    }
    for ( bargen.uOver( bar ); bargen >> m; ) {
	cout << m->i << " ";
    }
    cout << "\n";
}

// Local Variables: //
// compile-command: "g++ example_Stack.cc" //
// End: //

==> u%2B%2B_5.3.0.orig.tar.gz: u++-5.3.0/src/collection/example_Stack.cc <==
#include "uStack.h"
#include "stream.h"

class fred : public uColable {
  public:
    int i;
    fred( int p ) { i = p; }
};

class mary: public fred {
  public:
    mary( int i ) : fred( i ) {}
};

main() {
    uStack<fred> foo;
    uStackIter<fred> fooIter( foo );
    uStack<mary> bar;
    uStackIter<mary> barIter( bar );
    fred *f;
    mary *m;
    int i;

    // fred test

    for ( ; fooIter >> f; ) {
	cout << f->i << " ";
    }
    cout << "\n";
    
    for ( i = 0; i < 10; i += 1 ) {
	foo.push( new fred( 2 * i ) );
    }

    for ( fooIter.over( foo ); fooIter >> f; ) {
	cout << f->i << " ";
    }
    cout << "\n";
    
    for ( i = 0; i < 9; i += 1 ) {
	foo.pop();
    }

    for ( fooIter.over( foo ); fooIter >> f; ) {
	cout << f->i << " ";
    }
    cout << "\n";
    
    for ( i = 0; i < 10; i += 1 ) {
	foo.push( new fred( 2 * i + 1 ) );
    }
    for ( fooIter.over( foo ); fooIter >> f; ) {
	cout << f->i << " ";
    }
    cout << "\n";

    // mary test

    for ( ; barIter >> m; ) {
	cout << m->i << " ";
    }
    cout << "\n";
    
    for ( i = 0; i < 10; i += 1 ) {
	bar.push( new mary( 2 * i ) );
    }

    for ( barIter.over( bar ); barIter >> m; ) {
	cout << m->i << " ";
    }
    cout << "\n";
    
    for ( i = 0; i < 9; i += 1 ) {
	bar.pop();
    }

    for ( barIter.over( bar ); barIter >> m; ) {
	cout << m->i << " ";
    }
    cout << "\n";
    
    for ( i = 0; i < 10; i += 1 ) {
	bar.push( new mary( 2 * i + 1 ) );
    }
    for ( barIter.over( bar ); barIter >> m; ) {
	cout << m->i << " ";
    }
    cout << "\n";
}

// Local Variables: //
// compile-command: "g++ example_Stack.cc" //
// End: //
